@@ -284,6 +284,12 @@ struct PolylineRuler
         }
         return *ranges_;
     }
+    double range(int seg_idx) const { return ranges()[seg_idx]; }
+    double range(int seg_idx, double t) const
+    {
+        auto &ranges = this->ranges();
+        return ranges[seg_idx] * (1.0 - t) + ranges[seg_idx + 1] * t;
+    }
 
     double length() const { return ranges()[N_ - 1]; }
 
@@ -386,6 +392,15 @@ struct PolylineRuler
                            is_wgs84_);
     }
 
+    Eigen::Vector3d at(double range) const { return extended_along(range); }
+    Eigen::Vector3d at(int seg_idx) const { return polyline_.row(seg_idx); }
+    Eigen::Vector3d at(int seg_idx, double t) const
+    {
+        return interpolate(polyline_.row(seg_idx),     //
+                           polyline_.row(seg_idx + 1), //
+                           t, is_wgs84_);
+    }
+
     std::pair<Eigen::Vector3d, Eigen::Vector3d>
     arrow(double range, bool smooth_joint = true) const
     {
